@@ -36,6 +36,7 @@ class Collision:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     max_contacts: int = field(
@@ -43,6 +44,7 @@ class Collision:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     frame: List["Collision.Frame"] = field(
@@ -57,6 +59,7 @@ class Collision:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     geometry: Optional[Geometry] = field(
@@ -100,6 +103,7 @@ class Collision:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
@@ -119,8 +123,8 @@ class Collision:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -142,8 +146,8 @@ class Collision:
         frame: Name of frame which the pose is defined relative to.
         """
 
-        value: Optional[str] = field(
-            default=None,
+        value: str = field(
+            default="",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -207,6 +211,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             threshold: float = field(
@@ -214,6 +219,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -274,6 +280,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 use_patch_radius: bool = field(
@@ -281,6 +288,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 patch_radius: float = field(
@@ -288,6 +296,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 surface_radius: float = field(
@@ -295,6 +304,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 ode: Optional["Collision.Surface.Friction.Torsional.Ode"] = field(
@@ -321,6 +331,7 @@ class Collision:
                         metadata={
                             "type": "Element",
                             "namespace": "",
+                            "required": True,
                         },
                     )
 
@@ -347,6 +358,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 mu2: float = field(
@@ -354,6 +366,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 fdir1: str = field(
@@ -361,6 +374,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
                     },
                 )
@@ -369,6 +383,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 slip2: float = field(
@@ -376,6 +391,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -399,6 +415,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 friction2: float = field(
@@ -406,6 +423,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 fdir1: str = field(
@@ -413,6 +431,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
                     },
                 )
@@ -421,6 +440,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -467,6 +487,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             collide_without_contact_bitmask: int = field(
@@ -474,6 +495,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             collide_bitmask: int = field(
@@ -481,6 +503,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             poissons_ratio: float = field(
@@ -488,6 +511,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             elastic_modulus: float = field(
@@ -495,6 +519,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             ode: Optional["Collision.Surface.Contact.Ode"] = field(
@@ -536,6 +561,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 soft_erp: float = field(
@@ -543,6 +569,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 kp: float = field(
@@ -550,6 +577,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 kd: float = field(
@@ -557,6 +585,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 max_vel: float = field(
@@ -564,6 +593,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 min_depth: float = field(
@@ -571,6 +601,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -602,6 +633,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 soft_erp: float = field(
@@ -609,6 +641,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 kp: float = field(
@@ -616,6 +649,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 kd: float = field(
@@ -623,6 +657,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 split_impulse: bool = field(
@@ -630,6 +665,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 split_impulse_penetration_threshold: float = field(
@@ -637,6 +673,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -681,6 +718,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 stiffness: float = field(
@@ -688,6 +726,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 damping: float = field(
@@ -695,6 +734,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 flesh_mass_fraction: float = field(
@@ -702,5 +742,6 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
