@@ -56,6 +56,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     child: str = field(
@@ -63,6 +64,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     gearbox_ratio: float = field(
@@ -70,6 +72,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     gearbox_reference_body: str = field(
@@ -77,6 +80,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     thread_pitch: float = field(
@@ -84,6 +88,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     axis: Optional["Joint.Axis"] = field(
@@ -119,10 +124,11 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
-    sensor: Optional[Sensor] = field(
-        default=None,
+    sensor: List[Sensor] = field(
+        default_factory=list,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -170,6 +176,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
             },
         )
@@ -178,6 +185,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         dynamics: Optional["Joint.Axis.Dynamics"] = field(
@@ -218,6 +226,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             friction: float = field(
@@ -225,6 +234,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_reference: float = field(
@@ -232,6 +242,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_stiffness: float = field(
@@ -239,6 +250,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -270,6 +282,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             upper: float = field(
@@ -277,6 +290,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             effort: float = field(
@@ -284,6 +298,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -291,6 +306,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             stiffness: float = field(
@@ -298,6 +314,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             dissipation: float = field(
@@ -305,6 +322,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -335,6 +353,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
             },
         )
@@ -343,6 +362,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         dynamics: Optional["Joint.Axis2.Dynamics"] = field(
@@ -384,6 +404,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             friction: float = field(
@@ -391,6 +412,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_reference: float = field(
@@ -398,6 +420,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_stiffness: float = field(
@@ -405,6 +428,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -435,6 +459,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             upper: float = field(
@@ -442,6 +467,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             effort: float = field(
@@ -449,6 +475,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -456,6 +483,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             stiffness: float = field(
@@ -463,6 +491,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             dissipation: float = field(
@@ -470,6 +499,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -509,6 +539,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -528,6 +559,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -573,6 +605,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             cfm_damping: bool = field(
@@ -580,6 +613,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             implicit_spring_damper: bool = field(
@@ -587,6 +621,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             fudge_factor: float = field(
@@ -594,6 +629,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             cfm: float = field(
@@ -601,6 +637,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             erp: float = field(
@@ -608,6 +645,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             bounce: float = field(
@@ -615,6 +653,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             max_force: float = field(
@@ -622,6 +661,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -629,6 +669,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             limit: Optional["Joint.Physics.Ode.Limit"] = field(
@@ -661,6 +702,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 erp: float = field(
@@ -668,6 +710,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -685,6 +728,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 erp: float = field(
@@ -692,6 +736,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -713,6 +758,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
@@ -732,8 +778,8 @@ class Joint:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -755,8 +801,8 @@ class Joint:
         frame: Name of frame which the pose is defined relative to.
         """
 
-        value: Optional[str] = field(
-            default=None,
+        value: str = field(
+            default="",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
