@@ -53,6 +53,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     self_collide: bool = field(
@@ -60,6 +61,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     kinematic: bool = field(
@@ -67,6 +69,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     must_be_base_link: bool = field(
@@ -74,6 +77,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     velocity_decay: Optional["Link.VelocityDecay"] = field(
@@ -95,6 +99,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     inertial: Optional["Link.Inertial"] = field(
@@ -118,8 +123,8 @@ class Link:
             "namespace": "",
         },
     )
-    sensor: Optional[Sensor] = field(
-        default=None,
+    sensor: List[Sensor] = field(
+        default_factory=list,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -177,6 +182,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         angular: float = field(
@@ -184,6 +190,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -205,6 +212,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
@@ -224,8 +232,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -247,8 +255,8 @@ class Link:
         frame: Name of frame which the pose is defined relative to.
         """
 
-        value: Optional[str] = field(
-            default=None,
+        value: str = field(
+            default="",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -286,6 +294,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         inertia: Optional["Link.Inertial.Inertia"] = field(
@@ -307,6 +316,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -324,6 +334,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             ixy: float = field(
@@ -331,6 +342,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             ixz: float = field(
@@ -338,6 +350,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             iyy: float = field(
@@ -345,6 +358,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             iyz: float = field(
@@ -352,6 +366,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             izz: float = field(
@@ -359,6 +374,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -381,6 +397,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             name: Optional[str] = field(
@@ -401,8 +418,8 @@ class Link:
                     to.
                 """
 
-                value: Optional[str] = field(
-                    default=None,
+                value: str = field(
+                    default="",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -424,8 +441,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -460,6 +477,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         fov: float = field(
@@ -467,6 +485,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         near_clip: float = field(
@@ -474,6 +493,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         far_clip: float = field(
@@ -481,6 +501,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         frame: List["Link.Projector.Frame"] = field(
@@ -495,6 +516,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         plugin: List["Link.Projector.Plugin"] = field(
@@ -531,6 +553,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             name: Optional[str] = field(
@@ -551,8 +574,8 @@ class Link:
                     to.
                 """
 
-                value: Optional[str] = field(
-                    default=None,
+                value: str = field(
+                    default="",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -574,8 +597,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -651,6 +674,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pitch: float = field(
@@ -658,6 +682,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         gain: float = field(
@@ -665,6 +690,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         contact: Optional["Link.AudioSource.Contact"] = field(
@@ -679,6 +705,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         frame: List["Link.AudioSource.Frame"] = field(
@@ -693,6 +720,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -735,6 +763,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             name: Optional[str] = field(
@@ -755,8 +784,8 @@ class Link:
                     to.
                 """
 
-                value: Optional[str] = field(
-                    default=None,
+                value: str = field(
+                    default="",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -778,8 +807,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -808,6 +837,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
