@@ -59,6 +59,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     enable_wind: bool = field(
@@ -66,6 +67,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     self_collide: bool = field(
@@ -73,6 +75,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     kinematic: bool = field(
@@ -80,6 +83,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     must_be_base_link: bool = field(
@@ -87,6 +91,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     velocity_decay: Optional["Link.VelocityDecay"] = field(
@@ -108,6 +113,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     inertial: Optional["Link.Inertial"] = field(
@@ -131,8 +137,8 @@ class Link:
             "namespace": "",
         },
     )
-    sensor: Optional[Sensor] = field(
-        default=None,
+    sensor: List[Sensor] = field(
+        default_factory=list,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -204,6 +210,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         angular: float = field(
@@ -211,6 +218,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -232,6 +240,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
@@ -251,8 +260,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -274,8 +283,8 @@ class Link:
         frame: Name of frame which the pose is defined relative to.
         """
 
-        value: Optional[str] = field(
-            default=None,
+        value: str = field(
+            default="",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -313,6 +322,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         inertia: Optional["Link.Inertial.Inertia"] = field(
@@ -334,6 +344,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -351,6 +362,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             ixy: float = field(
@@ -358,6 +370,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             ixz: float = field(
@@ -365,6 +378,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             iyy: float = field(
@@ -372,6 +386,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             iyz: float = field(
@@ -379,6 +394,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             izz: float = field(
@@ -386,6 +402,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -408,6 +425,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             name: Optional[str] = field(
@@ -428,8 +446,8 @@ class Link:
                     to.
                 """
 
-                value: Optional[str] = field(
-                    default=None,
+                value: str = field(
+                    default="",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -451,8 +469,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -487,6 +505,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         fov: float = field(
@@ -494,6 +513,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         near_clip: float = field(
@@ -501,6 +521,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         far_clip: float = field(
@@ -508,6 +529,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         frame: List["Link.Projector.Frame"] = field(
@@ -522,6 +544,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         plugin: List["Link.Projector.Plugin"] = field(
@@ -558,6 +581,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             name: Optional[str] = field(
@@ -578,8 +602,8 @@ class Link:
                     to.
                 """
 
-                value: Optional[str] = field(
-                    default=None,
+                value: str = field(
+                    default="",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -601,8 +625,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -678,6 +702,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pitch: float = field(
@@ -685,6 +710,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         gain: float = field(
@@ -692,6 +718,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         contact: Optional["Link.AudioSource.Contact"] = field(
@@ -706,6 +733,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         frame: List["Link.AudioSource.Frame"] = field(
@@ -720,6 +748,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -762,6 +791,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             name: Optional[str] = field(
@@ -782,8 +812,8 @@ class Link:
                     to.
                 """
 
-                value: Optional[str] = field(
-                    default=None,
+                value: str = field(
+                    default="",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -805,8 +835,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -835,6 +865,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
@@ -927,6 +958,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         duration: float = field(
@@ -934,6 +966,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         size: str = field(
@@ -941,6 +974,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
             },
         )
@@ -949,6 +983,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
             },
         )
@@ -957,6 +992,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         rate: float = field(
@@ -964,6 +1000,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         min_velocity: float = field(
@@ -971,6 +1008,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         max_velocity: float = field(
@@ -978,6 +1016,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         scale_rate: float = field(
@@ -985,6 +1024,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         color_start: str = field(
@@ -992,6 +1032,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*\+?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){3}\+?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s*",
             },
         )
@@ -1000,6 +1041,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*\+?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){3}\+?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s*",
             },
         )
@@ -1022,6 +1064,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pose: "Link.ParticleEmitter.Pose" = field(
@@ -1029,6 +1072,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         material: Optional[Material] = field(
@@ -1062,8 +1106,8 @@ class Link:
             frame: Name of frame which the pose is defined relative to.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
