@@ -35,6 +35,7 @@ class Collision:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     max_contacts: int = field(
@@ -42,6 +43,7 @@ class Collision:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     pose: "Collision.Pose" = field(
@@ -49,6 +51,7 @@ class Collision:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     geometry: Optional[Geometry] = field(
@@ -84,8 +87,8 @@ class Collision:
             applied.
         """
 
-        value: Optional[str] = field(
-            default=None,
+        value: str = field(
+            default="",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -149,6 +152,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             threshold: float = field(
@@ -156,6 +160,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -217,6 +222,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 use_patch_radius: bool = field(
@@ -224,6 +230,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 patch_radius: float = field(
@@ -231,6 +238,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 surface_radius: float = field(
@@ -238,6 +246,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 ode: Optional["Collision.Surface.Friction.Torsional.Ode"] = field(
@@ -267,6 +276,7 @@ class Collision:
                         metadata={
                             "type": "Element",
                             "namespace": "",
+                            "required": True,
                         },
                     )
 
@@ -315,6 +325,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 mu2: float = field(
@@ -322,6 +333,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 fdir1: str = field(
@@ -329,6 +341,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
                     },
                 )
@@ -337,6 +350,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 slip2: float = field(
@@ -344,6 +358,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -380,6 +395,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 friction2: float = field(
@@ -387,6 +403,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 fdir1: str = field(
@@ -394,6 +411,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
                     },
                 )
@@ -402,6 +420,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -454,6 +473,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             collide_without_contact_bitmask: int = field(
@@ -461,6 +481,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             collide_bitmask: int = field(
@@ -468,6 +489,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             category_bitmask: int = field(
@@ -475,6 +497,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             poissons_ratio: float = field(
@@ -482,6 +505,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             elastic_modulus: float = field(
@@ -489,6 +513,7 @@ class Collision:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             ode: Optional["Collision.Surface.Contact.Ode"] = field(
@@ -530,6 +555,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 soft_erp: float = field(
@@ -537,6 +563,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 kp: float = field(
@@ -544,6 +571,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 kd: float = field(
@@ -551,6 +579,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 max_vel: float = field(
@@ -558,6 +587,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 min_depth: float = field(
@@ -565,6 +595,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -596,6 +627,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 soft_erp: float = field(
@@ -603,6 +635,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 kp: float = field(
@@ -610,6 +643,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 kd: float = field(
@@ -617,6 +651,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 split_impulse: bool = field(
@@ -624,6 +659,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 split_impulse_penetration_threshold: float = field(
@@ -631,6 +667,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -675,6 +712,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 stiffness: float = field(
@@ -682,6 +720,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 damping: float = field(
@@ -689,6 +728,7 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 flesh_mass_fraction: float = field(
@@ -696,5 +736,6 @@ class Collision:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
