@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import Optional
+from typing import List, Optional
 from .sensor import Sensor
 
 __NAMESPACE__ = "sdformat/v1.7/joint.xsd"
@@ -59,6 +59,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     child: str = field(
@@ -66,6 +67,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     gearbox_ratio: float = field(
@@ -73,6 +75,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     gearbox_reference_body: str = field(
@@ -80,6 +83,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     thread_pitch: float = field(
@@ -87,6 +91,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     axis: Optional["Joint.Axis"] = field(
@@ -115,10 +120,11 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
-    sensor: Optional[Sensor] = field(
-        default=None,
+    sensor: List[Sensor] = field(
+        default_factory=list,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -163,6 +169,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         xyz: "Joint.Axis.Xyz" = field(
@@ -170,6 +177,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         dynamics: Optional["Joint.Axis.Dynamics"] = field(
@@ -198,8 +206,8 @@ class Joint:
                 unit vector is expressed.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -234,6 +242,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             friction: float = field(
@@ -241,6 +250,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_reference: float = field(
@@ -248,6 +258,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_stiffness: float = field(
@@ -255,6 +266,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -283,6 +295,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             upper: float = field(
@@ -290,6 +303,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             effort: float = field(
@@ -297,6 +311,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -304,6 +319,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             stiffness: float = field(
@@ -311,6 +327,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             dissipation: float = field(
@@ -318,6 +335,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -345,6 +363,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         xyz: "Joint.Axis2.Xyz" = field(
@@ -352,6 +371,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         dynamics: Optional["Joint.Axis2.Dynamics"] = field(
@@ -380,8 +400,8 @@ class Joint:
                 unit vector is expressed.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -418,6 +438,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             friction: float = field(
@@ -425,6 +446,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_reference: float = field(
@@ -432,6 +454,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_stiffness: float = field(
@@ -439,6 +462,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -469,6 +493,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             upper: float = field(
@@ -476,6 +501,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             effort: float = field(
@@ -483,6 +509,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -490,6 +517,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             stiffness: float = field(
@@ -497,6 +525,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             dissipation: float = field(
@@ -504,6 +533,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -539,6 +569,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -558,6 +589,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -596,6 +628,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             implicit_spring_damper: bool = field(
@@ -603,6 +636,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             fudge_factor: float = field(
@@ -610,6 +644,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             cfm: float = field(
@@ -617,6 +652,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             erp: float = field(
@@ -624,6 +660,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             bounce: float = field(
@@ -631,6 +668,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             max_force: float = field(
@@ -638,6 +676,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -645,6 +684,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             limit: Optional["Joint.Physics.Ode.Limit"] = field(
@@ -677,6 +717,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 erp: float = field(
@@ -684,6 +725,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -701,6 +743,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 erp: float = field(
@@ -708,6 +751,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -721,8 +765,8 @@ class Joint:
             applied.
         """
 
-        value: Optional[str] = field(
-            default=None,
+        value: str = field(
+            default="",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
