@@ -78,6 +78,7 @@ class World:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
             "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
         },
     )
@@ -86,6 +87,7 @@ class World:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
             "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
         },
     )
@@ -104,12 +106,12 @@ class World:
             "namespace": "",
         },
     )
-    physics: Optional[Physics] = field(
-        default=None,
+    physics: List[Physics] = field(
+        default_factory=list,
         metadata={
             "type": "Element",
             "namespace": "",
-            "required": True,
+            "min_occurs": 1,
         },
     )
     scene: Optional[Scene] = field(
@@ -208,6 +210,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -226,6 +229,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
             },
         )
@@ -249,6 +253,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
@@ -263,6 +268,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pose: "World.Include.Pose" = field(
@@ -270,6 +276,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -283,8 +290,8 @@ class World:
                 applied.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -318,6 +325,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pressure: float = field(
@@ -325,6 +333,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         temperature_gradient: float = field(
@@ -332,6 +341,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         type: Optional[str] = field(
@@ -394,6 +404,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             projection_type: str = field(
@@ -401,6 +412,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             track_visual: Optional["World.Gui.Camera.TrackVisual"] = field(
@@ -415,6 +427,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             name: Optional[str] = field(
@@ -471,6 +484,7 @@ class World:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 min_dist: float = field(
@@ -478,6 +492,7 @@ class World:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 max_dist: float = field(
@@ -485,6 +500,7 @@ class World:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 static: bool = field(
@@ -492,6 +508,7 @@ class World:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 use_model_frame: bool = field(
@@ -499,6 +516,7 @@ class World:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 xyz: str = field(
@@ -506,6 +524,7 @@ class World:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
                     },
                 )
@@ -514,6 +533,7 @@ class World:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -527,8 +547,8 @@ class World:
                     applied.
                 """
 
-                value: Optional[str] = field(
-                    default=None,
+                value: str = field(
+                    default="",
                     metadata={
                         "required": True,
                         "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -604,6 +624,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
@@ -630,8 +651,8 @@ class World:
                 applied.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -700,6 +721,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         point: List[str] = field(
@@ -771,6 +793,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         world_frame_orientation: str = field(
@@ -778,6 +801,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         latitude_deg: float = field(
@@ -785,6 +809,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         longitude_deg: float = field(
@@ -792,6 +817,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         elevation: float = field(
@@ -799,6 +825,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         heading_deg: float = field(
@@ -806,6 +833,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -835,6 +863,7 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         distribution: Optional["World.Population.Distribution"] = field(
@@ -864,10 +893,11 @@ class World:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
-        model: List[Model] = field(
-            default_factory=list,
+        model: Optional[Model] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -911,6 +941,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             rows: int = field(
@@ -918,6 +949,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             cols: int = field(
@@ -925,6 +957,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             step: str = field(
@@ -932,6 +965,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
                 },
             )
@@ -953,6 +987,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
                 },
             )
@@ -973,6 +1008,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             length: float = field(
@@ -980,6 +1016,7 @@ class World:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -993,8 +1030,8 @@ class World:
                 applied.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
