@@ -1,5 +1,5 @@
 from dataclasses import dataclass, field
-from typing import Optional
+from typing import List, Optional
 from .sensor import Sensor
 
 __NAMESPACE__ = "sdformat/v1.8/joint.xsd"
@@ -59,6 +59,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     child: str = field(
@@ -66,6 +67,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     gearbox_ratio: float = field(
@@ -73,6 +75,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     gearbox_reference_body: str = field(
@@ -80,6 +83,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     thread_pitch: float = field(
@@ -87,6 +91,7 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     axis: Optional["Joint.Axis"] = field(
@@ -115,10 +120,11 @@ class Joint:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
-    sensor: Optional[Sensor] = field(
-        default=None,
+    sensor: List[Sensor] = field(
+        default_factory=list,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -162,6 +168,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         dynamics: Optional["Joint.Axis.Dynamics"] = field(
@@ -190,8 +197,8 @@ class Joint:
                 unit vector is expressed.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -226,6 +233,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             friction: float = field(
@@ -233,6 +241,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_reference: float = field(
@@ -240,6 +249,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_stiffness: float = field(
@@ -247,6 +257,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -275,6 +286,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             upper: float = field(
@@ -282,6 +294,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             effort: float = field(
@@ -289,6 +302,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -296,6 +310,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             stiffness: float = field(
@@ -303,6 +318,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             dissipation: float = field(
@@ -310,6 +326,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -336,6 +353,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         dynamics: Optional["Joint.Axis2.Dynamics"] = field(
@@ -364,8 +382,8 @@ class Joint:
                 unit vector is expressed.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -402,6 +420,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             friction: float = field(
@@ -409,6 +428,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_reference: float = field(
@@ -416,6 +436,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             spring_stiffness: float = field(
@@ -423,6 +444,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -453,6 +475,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             upper: float = field(
@@ -460,6 +483,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             effort: float = field(
@@ -467,6 +491,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -474,6 +499,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             stiffness: float = field(
@@ -481,6 +507,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             dissipation: float = field(
@@ -488,6 +515,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -523,6 +551,7 @@ class Joint:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -542,6 +571,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -580,6 +610,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             implicit_spring_damper: bool = field(
@@ -587,6 +618,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             fudge_factor: float = field(
@@ -594,6 +626,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             cfm: float = field(
@@ -601,6 +634,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             erp: float = field(
@@ -608,6 +642,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             bounce: float = field(
@@ -615,6 +650,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             max_force: float = field(
@@ -622,6 +658,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             velocity: float = field(
@@ -629,6 +666,7 @@ class Joint:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             limit: Optional["Joint.Physics.Ode.Limit"] = field(
@@ -661,6 +699,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 erp: float = field(
@@ -668,6 +707,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -685,6 +725,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
                 erp: float = field(
@@ -692,6 +733,7 @@ class Joint:
                     metadata={
                         "type": "Element",
                         "namespace": "",
+                        "required": True,
                     },
                 )
 
@@ -705,8 +747,8 @@ class Joint:
             applied.
         """
 
-        value: Optional[str] = field(
-            default=None,
+        value: str = field(
+            default="",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
