@@ -58,6 +58,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     enable_wind: bool = field(
@@ -65,6 +66,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     self_collide: bool = field(
@@ -72,6 +74,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     kinematic: bool = field(
@@ -79,6 +82,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     must_be_base_link: bool = field(
@@ -86,6 +90,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     velocity_decay: Optional["Link.VelocityDecay"] = field(
@@ -100,6 +105,7 @@ class Link:
         metadata={
             "type": "Element",
             "namespace": "",
+            "required": True,
         },
     )
     inertial: Optional["Link.Inertial"] = field(
@@ -123,8 +129,8 @@ class Link:
             "namespace": "",
         },
     )
-    sensor: Optional[Sensor] = field(
-        default=None,
+    sensor: List[Sensor] = field(
+        default_factory=list,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -196,6 +202,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         angular: float = field(
@@ -203,6 +210,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -216,8 +224,8 @@ class Link:
             applied.
         """
 
-        value: Optional[str] = field(
-            default=None,
+        value: str = field(
+            default="",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -254,6 +262,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pose: str = field(
@@ -261,6 +270,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
             },
         )
@@ -286,6 +296,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             ixy: float = field(
@@ -293,6 +304,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             ixz: float = field(
@@ -300,6 +312,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             iyy: float = field(
@@ -307,6 +320,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             iyz: float = field(
@@ -314,6 +328,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
             izz: float = field(
@@ -321,6 +336,7 @@ class Link:
                 metadata={
                     "type": "Element",
                     "namespace": "",
+                    "required": True,
                 },
             )
 
@@ -345,6 +361,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         fov: float = field(
@@ -352,6 +369,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         near_clip: float = field(
@@ -359,6 +377,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         far_clip: float = field(
@@ -366,6 +385,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pose: "Link.Projector.Pose" = field(
@@ -373,6 +393,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         plugin: List["Link.Projector.Plugin"] = field(
@@ -400,8 +421,8 @@ class Link:
                 applied.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -476,6 +497,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pitch: float = field(
@@ -483,6 +505,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         gain: float = field(
@@ -490,6 +513,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         contact: Optional["Link.AudioSource.Contact"] = field(
@@ -504,6 +528,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         pose: "Link.AudioSource.Pose" = field(
@@ -511,6 +536,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
 
@@ -544,8 +570,8 @@ class Link:
                 applied.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -574,6 +600,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         name: Optional[str] = field(
@@ -659,6 +686,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         duration: float = field(
@@ -666,6 +694,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         size: str = field(
@@ -673,6 +702,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
             },
         )
@@ -681,6 +711,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){2}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
             },
         )
@@ -689,6 +720,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         rate: float = field(
@@ -696,6 +728,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         min_velocity: float = field(
@@ -703,6 +736,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         max_velocity: float = field(
@@ -710,6 +744,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         scale_rate: float = field(
@@ -717,6 +752,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         color_start: str = field(
@@ -724,6 +760,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*\+?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){3}\+?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s*",
             },
         )
@@ -732,6 +769,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
                 "pattern": r"(\s*\+?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){3}\+?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s*",
             },
         )
@@ -754,6 +792,7 @@ class Link:
             metadata={
                 "type": "Element",
                 "namespace": "",
+                "required": True,
             },
         )
         material: Optional[Material] = field(
@@ -788,8 +827,8 @@ class Link:
                 applied.
             """
 
-            value: Optional[str] = field(
-                default=None,
+            value: str = field(
+                default="",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
